<?php

declare(strict_types=1);

namespace Drupal\polish_accounting\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemList;

/**
 * Defines custom methods for the document items field.
 */
final class AccountingDocumentItemList extends FieldItemList {

  /**
   * Get total values for all items.
   *
   * @return float[]
   *   Net and gross value of the document.
   */
  public function getTotals(): array {
    $result = [
      'net' => 0,
      'gross' => 0,
      'vat' => 0,
      'vat_summary' => [],
    ];
    foreach ($this as $item) {
      $net = $item->net_total;
      $result['net'] += $net;
      $vat = $item->vat_amount;
      $result['vat'] += $vat;
      $result['gross'] += ($net + $vat);
      if ($vat === 0) {
        continue;
      }
      if (!\array_key_exists($item->vat, $result['vat_summary'])) {
        $result['vat_summary'][$item->vat] = 0;
      }
      $result['vat_summary'][$item->vat] += $vat;
    }

    return $result;
  }

}
